@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: loadavg.c,v 1.6 1999/02/23 11:46:17 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,20 +28,16 @@ static const unsigned long _glibtop_sysdeps_loadavg = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_loadavg_s (glibtop *server)
 {
-    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
-
-    return 0;
+	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
 /* Provides load averange. */
 
-int
+void
 glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
-    memset (buf, 0, sizeof (glibtop_loadavg));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_loadavg));
 }
